@@ -18,12 +18,11 @@
 
 #include <config.h>
 
+#include <QIODevice>
 #include <QImage>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStringList>
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wnon-virtual-dtor"
 #include <fileref.h>
 #include <aifffile.h>
 #include <asffile.h>
@@ -48,7 +47,6 @@
 #include <itfile.h>
 #include <xmfile.h>
 #endif
-#pragma GCC diagnostic pop
 
 #include "APETagHelper.h"
 #include "ASFTagHelper.h"
@@ -183,7 +181,7 @@ TagHelper::splitUID( const QString &uidUrl ) const
     QString uid = uidUrl;
 
     if( uid.startsWith( QLatin1String("amarok-") ) )
-        uid = uid.remove( QRegExp( QStringLiteral("^(amarok-\\w+://).+$") ) );
+        uid = uid.remove( QRegularExpression( QStringLiteral("^(amarok-\\w+://).+$") ) );
 
     if( isValidUID( uid, UIDAFT ) )
         type = UIDAFT;
@@ -220,12 +218,12 @@ TagHelper::isValidUID( const QString &uid, const TagHelper::UIDType type ) const
     if( uid.length() >= 127 ) // the database can't handle longer uids
         return false;
 
-    QRegExp regexp( QStringLiteral("^$") );
+    QRegularExpression regexp( QStringLiteral("^$") );
 
     if( type == UIDAFT )
         regexp.setPattern( QStringLiteral("^[0-9a-fA-F]{32}$") );
 
-    return regexp.exactMatch( uid );
+    return QRegularExpression(QRegularExpression::anchoredPattern(regexp.pattern())).match( uid ).hasMatch();
 }
 
 TagLib::String
@@ -308,7 +306,9 @@ Meta::Tag::selectHelper( const TagLib::FileRef &fileref, bool forceCreation )
         {
             Amarok::FileType specificType = Amarok::Mp4;
             QString filename = QString::fromLatin1( fileref.file()->name() );
-            foreach( Amarok::FileType type, QList<Amarok::FileType>() << Amarok::M4a << Amarok::M4v )
+            QList<Amarok::FileType> types;
+            types << Amarok::M4a << Amarok::M4v;
+            for( Amarok::FileType type : types )
             {
                 if( filename.endsWith( Amarok::FileTypeSupport::toString( type ), Qt::CaseInsensitive ) )
                     specificType = type;
