@@ -33,6 +33,7 @@
 #include "playlist/PlaylistModelStack.h"
 #include "widgets/Osd.h"
 
+#include <QActionGroup>
 #include <QKeySequence>
 
 #include <KAuthorized>
@@ -71,11 +72,17 @@ safePlug( KActionCollection *ac, const char *name, QWidget *w )
 {
     if( ac )
     {
-        QAction *a = (QAction*) ac->action( name );
+        QAction *a = (QAction*) ac->action( QLatin1String(name) );
         if( a && w ) w->addAction( a );
     }
 }
 
+static void
+safePlug( KActionCollection *ac, QString name, QWidget *w )
+{
+    safePlug( ac, name.toLocal8Bit().constData(), w );
+}
+
 
 //////////////////////////////////////////////////////////////////////////////////////////
 // MenuAction && Menu
@@ -231,7 +238,7 @@ ToggleAction::ToggleAction( const QString &text, void ( *f ) ( bool ), KActionCo
         , m_function( f )
 {
     setText(text);
-    ac->addAction(name, this);
+    ac->addAction(QLatin1String(name), this);
 }
 
 void ToggleAction::setChecked( bool b )
@@ -263,7 +270,7 @@ SelectAction::SelectAction( const QString &text, void ( *f ) ( int ), KActionCol
 {
     PERF_LOG( "In SelectAction" );
     setText(text);
-    ac->addAction(name, this);
+    ac->addAction(QLatin1String(name), this);
 }
 
 void SelectAction::setCurrentItem( int n )
@@ -297,7 +304,7 @@ void SelectAction::setEnabled( bool b )
 void SelectAction::setIcons( QStringList icons )
 {
     m_icons = icons;
-    foreach( QAction *a, selectableActionGroup()->actions() )
+    for( QAction *a : selectableActionGroup()->actions() )
     {
         a->setIcon( QIcon::fromTheme(icons.takeFirst()) );
     }
@@ -313,7 +320,7 @@ QString SelectAction::currentIcon() const
 }
 
 QString SelectAction::currentText() const {
-    return KSelectAction::currentText() + "<br /><br />" + i18n("Click to change");
+    return KSelectAction::currentText() + QStringLiteral("<br /><br />") + i18n("Click to change");
 }
 
 
@@ -471,7 +478,7 @@ StopPlayingAfterCurrentTrackAction::StopPlayingAfterCurrentTrackAction( KActionC
     ac->addAction( QStringLiteral("stop_after_current"), this );
     setText( i18n( "Stop after current Track" ) );
     setIcon( QIcon::fromTheme(QStringLiteral("media-playback-stop-amarok")) );
-    KGlobalAccel::setGlobalShortcut(this, QKeySequence( Qt::META + Qt::SHIFT + Qt::Key_V ) );
+    KGlobalAccel::setGlobalShortcut(this, QKeySequence( Qt::META | Qt::SHIFT | Qt::Key_V ) );
     connect( this, &StopPlayingAfterCurrentTrackAction::triggered, this, &StopPlayingAfterCurrentTrackAction::stopPlayingAfterCurrentTrack );
 }
 
