@@ -18,15 +18,11 @@
 
 #include "BrowserBreadcrumbWidget.h"
 
-#include "amarokurls/AmarokUrl.h"
 #include "BrowserBreadcrumbItem.h"
 #include "BrowserCategoryList.h"
-#include "browsers/filebrowser/FileBrowser.h"
-#include "MainWindow.h"
 #include "widgets/BreadcrumbItemButton.h"
 
 #include <QBoxLayout>
-#include <QDir>
 #include <QMenu>
 #include <QResizeEvent>
 #include <QTimer>
@@ -201,9 +197,7 @@ void BrowserBreadcrumbWidget::showAsNeeded()
     allItems.first()->show();
     allItems.last()->show();
 
-    int numberOfItems = allItems.count();
-
-    for( int i = numberOfItems - 2; i > 0; i-- )
+    for( int i = allItems.count() - 2; i > 0; i-- )
     {
         if( allItems.at( i )->nominalWidth() <= spaceLeft )
         {
