@@ -30,12 +30,14 @@
 #include "EngineController.h"
 #include "MediaDeviceMonitor.h"
 #include "MemoryQueryMaker.h"
-#include "SvgHandler.h"
 #include "handler/AudioCdHandler.h"
 #include "support/AudioCdConnectionAssistant.h"
 #include "support/AudioCdDeviceInfo.h"
 
 #include <KIO/Job>
+#include <KIO/ListJob>
+#include <KIO/StatJob>
+#include <KIO/StoredTransferJob>
 #include <KIO/UDSEntry>
 
 #include <solid/device.h>
@@ -51,7 +53,7 @@
 
 using namespace Collections;
 
-static const QString unknownCddbId( "unknown" );
+static const QString unknownCddbId( QStringLiteral("unknown") );
 
 AudioCdCollectionFactory::AudioCdCollectionFactory()
     : MediaDeviceCollectionFactory<AudioCdCollection>( new AudioCdConnectionAssistant() )
@@ -85,12 +87,12 @@ AudioCdCollection::~AudioCdCollection()
 QUrl
 AudioCdCollection::audiocdUrl( const QString &path ) const
 {
-    QUrl url("audiocd:/" + path);
+    QUrl url(QStringLiteral("audiocd:/") + path);
 
     if( !m_device.isEmpty() )
     {
         QUrlQuery query;
-        query.addQueryItem( "device", m_device );
+        query.addQueryItem( QStringLiteral("device"), m_device );
         url.setQuery( query );
     }
 
@@ -118,7 +120,10 @@ AudioCdCollection::audioCdEntries( KIO::Job *job, const KIO::UDSEntryList &list
         const KIO::UDSEntry &entry = *it;
         QString name = entry.stringValue( KIO::UDSEntry::UDS_NAME );
         if( name.endsWith( QLatin1String(".txt") ) )
+        {
+            debug() << "got possible cddb entry" << name << "(" << entry.numberValue( KIO::UDSEntry::UDS_SIZE ) << ")";
             m_cddbTextFiles.insert( entry.numberValue( KIO::UDSEntry::UDS_SIZE ), audiocdUrl( name ) );
+        }
     }
 }
 
@@ -156,14 +161,21 @@ AudioCdCollection::infoFetchComplete( KJob *job )
     }
 
     KIO::StoredTransferJob *tjob = static_cast<KIO::StoredTransferJob*>( job );
-    QString cddbInfo = tjob->data();
+    QString cddbInfo;
 
     KEncodingProber prober;
     KEncodingProber::ProberState result = prober.feed( tjob->data() );
-    if( result != KEncodingProber::NotMe )
+    if( result == KEncodingProber::FoundIt )
+    {
         cddbInfo = QTextCodec::codecForName( prober.encoding() )->toUnicode( tjob->data() );
+        debug() << "Encoding" << prober.encoding()<<"(confidence"<<prober.confidence()<<")";
+    }
+    else // Encoding detection failed. This is 2020's, try UTF8.
+    {
+        cddbInfo = QString::fromUtf8( tjob->data() );
+        debug() << "Not sure about encoding (confidence" << prober.confidence() << "), so using UTF8.";
+    }
 
-    debug() << "Encoding: " << prober.encoding();
     debug() << "got cddb info: " << cddbInfo;
     if (cddbInfo.length() == 0) {
         job->deleteLater();
@@ -179,16 +191,16 @@ AudioCdCollection::infoFetchComplete( KJob *job )
     QString year;
     QString genre;
 
-    startIndex = cddbInfo.indexOf( "DTITLE=", 0 );
+    startIndex = cddbInfo.indexOf( QStringLiteral("DTITLE="), 0 );
     if ( startIndex != -1 )
     {
         startIndex += 7;
-        endIndex = cddbInfo.indexOf( "\n", startIndex );
+        endIndex = cddbInfo.indexOf( QStringLiteral("\n"), startIndex );
         QString compoundTitle = cddbInfo.mid( startIndex, endIndex - startIndex );
 
         debug() << "compoundTitle: " << compoundTitle;
 
-        QStringList compoundTitleList = compoundTitle.split( " / " );
+        QStringList compoundTitleList = compoundTitle.split( QStringLiteral(" / ") );
 
         artist = compoundTitleList.at( 0 );
         album = compoundTitleList.at( 1 );
@@ -203,11 +215,11 @@ AudioCdCollection::infoFetchComplete( KJob *job )
     memoryCollection()->addAlbum( Meta::AlbumPtr::staticCast( albumPtr ) );
 
 
-    startIndex = cddbInfo.indexOf( "DYEAR=", 0 );
+    startIndex = cddbInfo.indexOf( QStringLiteral("DYEAR="), 0 );
     if ( startIndex != -1 )
     {
         startIndex += 6;
-        endIndex = cddbInfo.indexOf( "\n", startIndex );
+        endIndex = cddbInfo.indexOf( QStringLiteral("\n"), startIndex );
         year = cddbInfo.mid( startIndex, endIndex - startIndex );
     }
 
@@ -215,11 +227,11 @@ AudioCdCollection::infoFetchComplete( KJob *job )
     memoryCollection()->addYear( Meta::YearPtr::staticCast( yearPtr ) );
 
 
-    startIndex = cddbInfo.indexOf( "DGENRE=", 0 );
+    startIndex = cddbInfo.indexOf( QStringLiteral("DGENRE="), 0 );
     if ( startIndex != -1 )
     {
         startIndex += 7;
-        endIndex = cddbInfo.indexOf( "\n", startIndex );
+        endIndex = cddbInfo.indexOf( QStringLiteral("\n"), startIndex );
         genre = cddbInfo.mid( startIndex, endIndex - startIndex );
     }
 
@@ -228,30 +240,30 @@ AudioCdCollection::infoFetchComplete( KJob *job )
 
     m_discCddbId = unknownCddbId;
 
-    startIndex = cddbInfo.indexOf( "DISCID=", 0 );
+    startIndex = cddbInfo.indexOf( QStringLiteral("DISCID="), 0 );
     if ( startIndex != -1 )
     {
         startIndex += 7;
-        endIndex = cddbInfo.indexOf( "\n", startIndex );
+        endIndex = cddbInfo.indexOf( QStringLiteral("\n"), startIndex );
         m_discCddbId = cddbInfo.mid( startIndex, endIndex - startIndex );
     }
 
     //MediaDeviceMonitor::instance()->setCurrentCdId( m_discCddbId );
 
     //get the list of tracknames
-    startIndex = cddbInfo.indexOf( "TTITLE0=", 0 );
+    startIndex = cddbInfo.indexOf( QStringLiteral("TTITLE0="), 0 );
     if ( startIndex != -1 )
     {
-        endIndex = cddbInfo.indexOf( "\nEXTD=", startIndex );
+        endIndex = cddbInfo.indexOf( QStringLiteral("\nEXTD="), startIndex );
         QString tracksBlock = cddbInfo.mid( startIndex, endIndex - startIndex );
         debug() << "Tracks block: " << tracksBlock;
-        QStringList tracksBlockList = tracksBlock.split( '\n' );
+        QStringList tracksBlockList = tracksBlock.split( QLatin1Char('\n') );
 
         int numberOfTracks = tracksBlockList.count();
 
         for ( int i = 0; i < numberOfTracks; i++ )
         {
-            QString prefix = "TTITLE" + QString::number( i ) + '=';
+            QString prefix = QStringLiteral("TTITLE") + QString::number( i ) + QLatin1Char('=');
             debug() << "prefix: " << prefix;
             QString trackName = tracksBlockList.at( i );
             trackName = trackName.remove( prefix );
@@ -259,9 +271,9 @@ AudioCdCollection::infoFetchComplete( KJob *job )
             QString trackArtist;
             //check if a track artist is included in the track name:
 
-            if ( trackName.contains( " / " ) )
+            if ( trackName.contains( QStringLiteral(" / ") ) )
             {
-                QStringList trackArtistList = trackName.split( " / " );
+                QStringList trackArtistList = trackName.split( QStringLiteral(" / ") );
                 trackName = trackArtistList.at( 1 );
                 trackArtist = trackArtistList.at( 0 );
 
@@ -269,18 +281,18 @@ AudioCdCollection::infoFetchComplete( KJob *job )
 
             debug() << "Track name: " << trackName;
 
-            QString padding = (i + 1) < 10 ? "0" : QString();
+            QString padding = (i + 1) < 10 ? QStringLiteral("0") : QString();
 
             QString baseFileName = m_fileNamePattern;
             debug() << "Track Base File Name (before): " << baseFileName;
 
-            baseFileName.replace( "%{title}", trackName, Qt::CaseInsensitive );
-            baseFileName.replace( "%{number}", padding  + QString::number( i + 1 ), Qt::CaseInsensitive );
-            baseFileName.replace( "%{albumtitle}", album, Qt::CaseInsensitive );
-            baseFileName.replace( "%{trackartist}", trackArtist, Qt::CaseInsensitive );
-            baseFileName.replace( "%{albumartist}", artist, Qt::CaseInsensitive );
-            baseFileName.replace( "%{year}", year, Qt::CaseInsensitive );
-            baseFileName.replace( "%{genre}", genre, Qt::CaseInsensitive );
+            baseFileName.replace( QStringLiteral("%{title}"), trackName, Qt::CaseInsensitive );
+            baseFileName.replace( QStringLiteral("%{number}"), padding  + QString::number( i + 1 ), Qt::CaseInsensitive );
+            baseFileName.replace( QStringLiteral("%{albumtitle}"), album, Qt::CaseInsensitive );
+            baseFileName.replace( QStringLiteral("%{trackartist}"), trackArtist, Qt::CaseInsensitive );
+            baseFileName.replace( QStringLiteral("%{albumartist}"), artist, Qt::CaseInsensitive );
+            baseFileName.replace( QStringLiteral("%{year}"), year, Qt::CaseInsensitive );
+            baseFileName.replace( QStringLiteral("%{genre}"), genre, Qt::CaseInsensitive );
 
             //we hack the url so the engine controller knows what track on the CD to play..
             QUrl baseUrl = audiocdUrl( m_discCddbId + QLatin1Char('/') + QString::number( i + 1 ) );
@@ -347,21 +359,21 @@ AudioCdCollection::checkForStartPlayRequest()
 QString
 AudioCdCollection::trackBaseFileName( int i ) const
 {
-    return QStringLiteral( "Track%1" ).arg( i, 2, 10, QChar('0') );
+    return QStringLiteral( "Track%1" ).arg( i, 2, 10, QLatin1Char('0') );
 }
 
 
 QString
 AudioCdCollection::trackWavFileName( int i ) const
 {
-    return trackBaseFileName( i ) + ".wav";
+    return trackBaseFileName( i ) + QStringLiteral(".wav");
 }
 
 
 QString
 AudioCdCollection::trackDisplayName( int i ) const
 {
-    return i18n( "Track" ) + ' ' + QString::number( i );
+    return i18n( "Track" ) + QLatin1Char(' ') + QString::number( i );
 }
 
 
@@ -394,7 +406,7 @@ AudioCdCollection::prettyName() const
 QIcon
 AudioCdCollection::icon() const
 {
-    return QIcon::fromTheme( "media-optical-audio" );
+    return QIcon::fromTheme( QStringLiteral("media-optical-audio") );
 }
 
 void
@@ -409,13 +421,13 @@ AudioCdCollection::encodingFormat() const
     switch( m_encodingFormat )
     {
         case WAV:
-            return "wav";
+            return QStringLiteral("wav");
         case FLAC:
-            return "flac";
+            return QStringLiteral("flac");
         case OGG:
-            return "ogg";
+            return QStringLiteral("ogg");
         case MP3:
-            return "mp3";
+            return QStringLiteral("mp3");
     }
     return QString();
 }
@@ -428,11 +440,11 @@ AudioCdCollection::copyableFilePath( const QString &fileName ) const
         case WAV:
             return audiocdUrl( fileName ).url();
         case FLAC:
-            return audiocdUrl( "FLAC/" + fileName ).url();
+            return audiocdUrl( QStringLiteral("FLAC/") + fileName ).url();
         case OGG:
-            return audiocdUrl( "Ogg Vorbis/" + fileName ).url();
+            return audiocdUrl( QStringLiteral("Ogg Vorbis/") + fileName ).url();
         case MP3:
-            return audiocdUrl( "MP3/" + fileName ).url();
+            return audiocdUrl( QStringLiteral("MP3/") + fileName ).url();
     }
     return QString();
 }
@@ -459,7 +471,7 @@ AudioCdCollection::eject()
 
     if ( track )
     {
-        if( track->playableUrl().url().startsWith( "audiocd:/" ) )
+        if( track->playableUrl().url().startsWith( QStringLiteral("audiocd:/") ) )
             The::engineController()->stop();
     }
 
@@ -545,8 +557,8 @@ AudioCdCollection::noInfoAvailable()
 void
 AudioCdCollection::readAudioCdSettings()
 {
-    KSharedConfigPtr conf = KSharedConfig::openConfig( "kcmaudiocdrc" );
-    KConfigGroup filenameConf = conf->group( "FileName" );
+    KSharedConfigPtr conf = KSharedConfig::openConfig( QStringLiteral("kcmaudiocdrc") );
+    KConfigGroup filenameConf = conf->group( QStringLiteral("FileName") );
 
     m_fileNamePattern = filenameConf.readEntry( "file_name_template", "%{trackartist} - %{number} - %{title}" );
     m_albumNamePattern = filenameConf.readEntry( "album_name_template", "%{albumartist} - %{albumtitle}" );
@@ -555,7 +567,7 @@ AudioCdCollection::readAudioCdSettings()
 bool
 AudioCdCollection::possiblyContainsTrack( const QUrl &url ) const
 {
-    return url.scheme() == "audiocd";
+    return url.scheme() == QStringLiteral("audiocd");
 }
 
 Meta::TrackPtr
@@ -565,15 +577,16 @@ AudioCdCollection::trackForUrl( const QUrl &url )
     if( memoryCollection()->trackMap().contains( url.url() ) )
         return memoryCollection()->trackMap().value( url.url() );
 
-    QRegExp trackUrlScheme( "^audiocd:/([a-zA-Z0-9]*)/([0-9]{1,})" );
-    if( trackUrlScheme.indexIn( url.url() ) != 0 )
+    QRegularExpression trackUrlScheme( QStringLiteral("^audiocd:/([a-zA-Z0-9]*)/([0-9]{1,})") );
+    if( url.url().indexOf( trackUrlScheme ) != 0 )
     {
         warning() << __PRETTY_FUNCTION__ << url.url() << "doesn't have correct scheme" << trackUrlScheme;
         return Meta::TrackPtr();
     }
+    QRegularExpressionMatch rmatch = trackUrlScheme.match( url.url() );
 
-    const QString trackCddbId = trackUrlScheme.capturedTexts().value( 1 );
-    const int trackNumber = trackUrlScheme.capturedTexts().value( 2 ).toInt();
+    const QString trackCddbId = rmatch.capturedTexts().value( 1 );
+    const int trackNumber = rmatch.capturedTexts().value( 2 ).toInt();
     if( !trackCddbId.isEmpty() && trackCddbId != unknownCddbId &&
         !m_discCddbId.isEmpty() && m_discCddbId != unknownCddbId &&
         trackCddbId != m_discCddbId )
@@ -583,7 +596,7 @@ AudioCdCollection::trackForUrl( const QUrl &url )
         return Meta::TrackPtr();
     }
 
-    foreach( const Meta::TrackPtr &track, memoryCollection()->trackMap() )
+    for( const Meta::TrackPtr &track : memoryCollection()->trackMap() )
     {
         if( track->trackNumber() == trackNumber )
             return track;
@@ -596,10 +609,10 @@ AudioCdCollection::trackForUrl( const QUrl &url )
 void
 AudioCdCollection::updateProxyTracks()
 {
-    foreach( const QUrl &url, m_proxyMap.keys() )
+    for( const QUrl &url : m_proxyMap.keys() )
     {
 
-        QString urlString = url.url().remove( "audiocd:/" );
+        QString urlString = url.url().remove( QStringLiteral("audiocd:/") );
         const QStringList &parts = urlString.split( QLatin1Char('/') );
 
         if( parts.count() != 2 )
@@ -612,7 +625,7 @@ AudioCdCollection::updateProxyTracks()
 
         const int trackNumber = parts.at( 1 ).toInt();
 
-        foreach( const Meta::TrackPtr &track, memoryCollection()->trackMap().values() )
+        for( const Meta::TrackPtr &track : memoryCollection()->trackMap().values() )
         {
             if( track->trackNumber() == trackNumber )
             {
