@@ -86,7 +86,7 @@ XSPFPlaylist::load()
 {
     XSPFTrackList xspfTracks = trackList();
 
-    foreach( const XSPFTrack &track, xspfTracks )
+    for( const XSPFTrack &track : xspfTracks )
     {
        MetaProxy::TrackPtr proxyTrack( new MetaProxy::Track( track.location ) );
        //Fill in values from xspf..
@@ -484,7 +484,7 @@ XSPFPlaylist::trackList()
             {
                 if( subSubNode.nodeName() == QLatin1String("location") )
                 {
-                    QByteArray path = subSubNode.firstChild().nodeValue().toLatin1();
+                    QByteArray path = subSubNode.firstChild().nodeValue().toUtf8();
                     path.replace( '\\', '/' );
 
                     QUrl url = getAbsolutePath( QUrl::fromEncoded( path ) );
@@ -531,8 +531,7 @@ XSPFPlaylist::setTrackList( Meta::TrackList trackList, bool append )
 
     QDomNode node = createElement( QStringLiteral("trackList") );
 
-    Meta::TrackPtr track;
-    foreach( track, trackList ) // krazy:exclude=foreach
+    for( auto track : trackList )
     {
         QDomNode subNode = createElement( QStringLiteral("track") );
 
@@ -632,7 +631,7 @@ XSPFPlaylist::setQueue( const QList<int> &queue )
 {
     QDomElement q = createElement( QStringLiteral("queue") );
 
-    foreach( int row, queue )
+    for( int row : queue )
     {
         QDomElement qTrack = createElement( QStringLiteral("track") );
         qTrack.appendChild( createTextNode( QString::number( row ) ) );
@@ -643,6 +642,8 @@ XSPFPlaylist::setQueue( const QList<int> &queue )
     extension.setAttribute( QStringLiteral("application"), QStringLiteral("http://amarok.kde.org") );
     extension.appendChild( q );
 
+    if( firstChild().isNull() )
+        save( m_relativePaths );
     QDomNode root = firstChild();
     root.appendChild( extension );
 }
