@@ -52,7 +52,9 @@
 #include <QFile>
 #include <QMap>
 #include <QMessageBox>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QNetworkConfigurationManager>
+#endif
 #include <QProgressDialog>
 #include <QStandardPaths>
 #include <QTimer>
@@ -110,9 +112,9 @@ SqlPodcastProvider::SqlPodcastProvider()
     {
         debug() << "creating Podcast Tables";
         createTables();
-        sqlStorage->query( "INSERT INTO admin(component,version) "
-                           "VALUES('" + key + "',"
-                           + QString::number( PODCAST_DB_VERSION ) + ");" );
+        sqlStorage->query( QStringLiteral("INSERT INTO admin(component,version) "
+                           "VALUES('") + key + QStringLiteral("',")
+                           + QString::number( PODCAST_DB_VERSION ) + QStringLiteral(");") );
     }
     else
     {
@@ -137,7 +139,7 @@ SqlPodcastProvider::startTimer()
         return; //already started with correct interval
 
     //and only start if at least one channel has autoscan enabled
-    foreach( Podcasts::SqlPodcastChannelPtr channel, m_channels )
+    for( Podcasts::SqlPodcastChannelPtr channel : m_channels )
     {
         if( channel->autoScan() )
         {
@@ -149,10 +151,10 @@ SqlPodcastProvider::startTimer()
 
 SqlPodcastProvider::~SqlPodcastProvider()
 {
-    foreach( Podcasts::SqlPodcastChannelPtr channel, m_channels )
+    for( Podcasts::SqlPodcastChannelPtr channel : m_channels )
     {
         channel->updateInDb();
-        foreach( Podcasts::SqlPodcastEpisodePtr episode, channel->sqlEpisodes() )
+        for( Podcasts::SqlPodcastEpisodePtr episode : channel->sqlEpisodes() )
             episode->updateInDb();
     }
     m_channels.clear();
@@ -173,9 +175,9 @@ SqlPodcastProvider::loadPodcasts()
     if( !sqlStorage )
         return;
 
-    QStringList results = sqlStorage->query( "SELECT id, url, title, weblink, image"
+    QStringList results = sqlStorage->query( QStringLiteral( "SELECT id, url, title, weblink, image"
         ", description, copyright, directory, labels, subscribedate, autoscan, fetchtype"
-        ", haspurge, purgecount, writetags, filenamelayout FROM podcastchannels;" );
+        ", haspurge, purgecount, writetags, filenamelayout FROM podcastchannels;") );
 
     int rowLength = 16;
     for( int i = 0; i < results.size(); i += rowLength )
@@ -203,10 +205,10 @@ SqlPodcastProvider::sqlEpisodeForString( const QString &string )
     if( !sqlStorage )
         return SqlPodcastEpisodePtr();
 
-    QString command = "SELECT id, url, channel, localurl, guid, "
+    QString command = QStringLiteral("SELECT id, url, channel, localurl, guid, "
             "title, subtitle, sequencenumber, description, mimetype, pubdate, "
             "duration, filesize, isnew, iskeep FROM podcastepisodes "
-            "WHERE guid='%1' OR url='%1' OR localurl='%1' ORDER BY id DESC;";
+            "WHERE guid='%1' OR url='%1' OR localurl='%1' ORDER BY id DESC;");
     command = command.arg( sqlStorage->escape( string ) );
     QStringList dbResult = sqlStorage->query( command );
 
@@ -215,27 +217,26 @@ SqlPodcastProvider::sqlEpisodeForString( const QString &string )
 
     int episodeId = dbResult[0].toInt();
     int channelId = dbResult[2].toInt();
-    bool found = false;
+
     Podcasts::SqlPodcastChannelPtr channel;
-    foreach( channel, m_channels )
+    for( const auto &ch : m_channels )
     {
-        if( channel->dbId() == channelId )
+        if( ch->dbId() == channelId )
         {
-            found = true;
+            channel = ch;
             break;
         }
     }
 
-    if( !found )
+    if( channel.isNull() )
     {
-        error() << QString( "There is a track in the database with url/guid=%1 (%2) "
+        error() << QStringLiteral( "There is a track in the database with url/guid=%1 (%2) "
                             "but there is no channel with dbId=%3 in our list!" )
                 .arg( string ).arg( episodeId ).arg( channelId );
         return SqlPodcastEpisodePtr();
     }
 
-    Podcasts::SqlPodcastEpisodePtr episode;
-    foreach( episode, channel->sqlEpisodes() )
+    for( auto episode : channel->sqlEpisodes() )
         if( episode->dbId() == episodeId )
             return episode;
 
@@ -251,8 +252,8 @@ SqlPodcastProvider::possiblyContainsTrack( const QUrl &url ) const
     if( !sqlStorage )
         return false;
 
-    QString command = "SELECT id FROM podcastepisodes WHERE guid='%1' OR url='%1' "
-                      "OR localurl='%1';";
+    QString command = QStringLiteral("SELECT id FROM podcastepisodes WHERE guid='%1' OR url='%1' "
+                                     "OR localurl='%1';");
     command = command.arg( sqlStorage->escape( url.url() ) );
 
     QStringList dbResult = sqlStorage->query( command );
@@ -290,13 +291,13 @@ SqlPodcastProvider::providerActions()
     {
         QAction *updateAllAction = new QAction( QIcon::fromTheme( QStringLiteral("view-refresh-amarok") ),
                 i18n( "&Update All Channels" ), this );
-        updateAllAction->setProperty( "popupdropper_svg_id", "update" );
+        updateAllAction->setProperty( "popupdropper_svg_id", QStringLiteral("update") );
         connect( updateAllAction, &QAction::triggered, this, &SqlPodcastProvider::updateAll );
         m_providerActions << updateAllAction;
 
         QAction *configureAction = new QAction( QIcon::fromTheme( QStringLiteral("configure") ),
                 i18n( "&Configure General Settings" ), this );
-        configureAction->setProperty( "popupdropper_svg_id", "configure" );
+        configureAction->setProperty( "popupdropper_svg_id", QStringLiteral("configure") );
         connect( configureAction, &QAction::triggered, this, &SqlPodcastProvider::slotConfigureProvider );
         m_providerActions << configureAction;
 
@@ -314,7 +315,7 @@ SqlPodcastProvider::playlistActions( const Playlists::PlaylistList &playlists )
 {
     QActionList actions;
     SqlPodcastChannelList sqlChannels;
-    foreach( const Playlists::PlaylistPtr &playlist, playlists )
+    for( const Playlists::PlaylistPtr &playlist : playlists )
     {
         SqlPodcastChannelPtr sqlChannel = SqlPodcastChannel::fromPlaylistPtr( playlist );
         if( sqlChannel )
@@ -328,7 +329,7 @@ SqlPodcastProvider::playlistActions( const Playlists::PlaylistList &playlists )
     if( m_configureChannelAction == nullptr )
     {
         m_configureChannelAction = new QAction( QIcon::fromTheme( QStringLiteral("configure") ), i18n( "&Configure" ), this );
-        m_configureChannelAction->setProperty( "popupdropper_svg_id", "configure" );
+        m_configureChannelAction->setProperty( "popupdropper_svg_id", QStringLiteral("configure") );
         connect( m_configureChannelAction, &QAction::triggered, this, &SqlPodcastProvider::slotConfigureChannel );
     }
     //only one channel can be configured at a time.
@@ -341,7 +342,7 @@ SqlPodcastProvider::playlistActions( const Playlists::PlaylistList &playlists )
     if( m_removeAction == nullptr )
     {
         m_removeAction = new QAction( QIcon::fromTheme( QStringLiteral("news-unsubscribe") ), i18n( "&Remove Subscription" ), this );
-        m_removeAction->setProperty( "popupdropper_svg_id", "remove" );
+        m_removeAction->setProperty( "popupdropper_svg_id", QStringLiteral("remove") );
         connect( m_removeAction, &QAction::triggered, this, &SqlPodcastProvider::slotRemoveChannels );
     }
     m_removeAction->setData( QVariant::fromValue( sqlChannels ) );
@@ -350,7 +351,7 @@ SqlPodcastProvider::playlistActions( const Playlists::PlaylistList &playlists )
     if( m_updateAction == nullptr )
     {
         m_updateAction = new QAction( QIcon::fromTheme( QStringLiteral("view-refresh-amarok") ), i18n( "&Update Channel" ), this );
-        m_updateAction->setProperty( "popupdropper_svg_id", "update" );
+        m_updateAction->setProperty( "popupdropper_svg_id", QStringLiteral("update") );
         connect( m_updateAction, &QAction::triggered, this, &SqlPodcastProvider::slotUpdateChannels );
     }
     m_updateAction->setData( QVariant::fromValue( sqlChannels ) );
@@ -363,7 +364,7 @@ QActionList
 SqlPodcastProvider::trackActions( const QMultiHash<Playlists::PlaylistPtr, int> &playlistTracks )
 {
     SqlPodcastEpisodeList episodes;
-    foreach( const Playlists::PlaylistPtr &playlist, playlistTracks.uniqueKeys() )
+    for( const Playlists::PlaylistPtr &playlist : playlistTracks.uniqueKeys() )
     {
         SqlPodcastChannelPtr sqlChannel = SqlPodcastChannel::fromPlaylistPtr( playlist );
         if( !sqlChannel )
@@ -372,7 +373,7 @@ SqlPodcastProvider::trackActions( const QMultiHash<Playlists::PlaylistPtr, int>
         SqlPodcastEpisodeList channelEpisodes = sqlChannel->sqlEpisodes();
         QList<int> trackPositions = playlistTracks.values( playlist );
         std::sort( trackPositions.begin(), trackPositions.end() );
-        foreach( int trackPosition, trackPositions )
+        for( int trackPosition : trackPositions )
         {
             if( trackPosition >= 0 && trackPosition < channelEpisodes.count() )
                 episodes << channelEpisodes.at( trackPosition );
@@ -386,7 +387,7 @@ SqlPodcastProvider::trackActions( const QMultiHash<Playlists::PlaylistPtr, int>
     if( m_downloadAction == nullptr )
     {
         m_downloadAction = new QAction( QIcon::fromTheme( QStringLiteral("go-down") ), i18n( "&Download Episode" ), this );
-        m_downloadAction->setProperty( "popupdropper_svg_id", "download" );
+        m_downloadAction->setProperty( "popupdropper_svg_id", QStringLiteral("download") );
         connect( m_downloadAction, &QAction::triggered, this, &SqlPodcastProvider::slotDownloadEpisodes );
     }
 
@@ -394,7 +395,7 @@ SqlPodcastProvider::trackActions( const QMultiHash<Playlists::PlaylistPtr, int>
     {
         m_deleteAction = new QAction( QIcon::fromTheme( QStringLiteral("edit-delete") ),
             i18n( "&Delete Downloaded Episode" ), this );
-        m_deleteAction->setProperty( "popupdropper_svg_id", "delete" );
+        m_deleteAction->setProperty( "popupdropper_svg_id", QStringLiteral("delete") );
         m_deleteAction->setObjectName( QStringLiteral("deleteAction") );
         connect( m_deleteAction, &QAction::triggered, this, &SqlPodcastProvider::slotDeleteDownloadedEpisodes );
     }
@@ -403,7 +404,7 @@ SqlPodcastProvider::trackActions( const QMultiHash<Playlists::PlaylistPtr, int>
     {
         m_writeTagsAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-edit-amarok") ),
             i18n( "&Write Feed Information to File" ), this );
-        m_writeTagsAction->setProperty( "popupdropper_svg_id", "edit" );
+        m_writeTagsAction->setProperty( "popupdropper_svg_id", QStringLiteral("edit") );
         connect( m_writeTagsAction, &QAction::triggered, this, &SqlPodcastProvider::slotWriteTagsToFiles );
     }
 
@@ -414,14 +415,14 @@ SqlPodcastProvider::trackActions( const QMultiHash<Playlists::PlaylistPtr, int>
         m_keepAction->setToolTip( i18n( "Toggle the \"keep\" downloaded file status of "
                 "this podcast episode. Downloaded files with this status wouldn't be "
                 "deleted even if we apply a purge." ) );
-        m_keepAction->setProperty( "popupdropper_svg_id", "keep" );
+        m_keepAction->setProperty( "popupdropper_svg_id", QStringLiteral("keep") );
         m_keepAction->setCheckable( true );
         connect( m_keepAction, &QAction::triggered, this, &SqlPodcastProvider::slotSetKeep );
     }
 
     SqlPodcastEpisodeList remoteEpisodes;
     SqlPodcastEpisodeList keptDownloadedEpisodes, unkeptDownloadedEpisodes;
-    foreach( const SqlPodcastEpisodePtr &episode, episodes )
+    for( const SqlPodcastEpisodePtr &episode : episodes )
     {
         if( episode->localUrl().isEmpty() )
             remoteEpisodes << episode;
@@ -488,7 +489,7 @@ SqlPodcastProvider::addPodcast( const QUrl &url )
 void
 SqlPodcastProvider::updateAll()
 {
-    foreach( Podcasts::SqlPodcastChannelPtr channel, m_channels )
+    for( Podcasts::SqlPodcastChannelPtr channel : m_channels )
         updateSqlChannel( channel );
 }
 
@@ -500,8 +501,8 @@ SqlPodcastProvider::subscribe( const QUrl &url )
 
     if( m_updatingChannels >= m_maxConcurrentUpdates )
     {
-        debug() << QString( "Maximum concurrent updates (%1) reached. "
-                            "Queueing \"%2\" for subscribing." )
+        debug() << QStringLiteral( "Maximum concurrent updates (%1) reached. "
+                                   "Queueing \"%2\" for subscribing." )
                         .arg( m_maxConcurrentUpdates )
                         .arg( url.url() );
         m_subscribeQueue << url;
@@ -591,7 +592,7 @@ void
 SqlPodcastProvider::configureProvider()
 {
     m_providerSettingsDialog = new QDialog( The::mainWindow() );
-    QWidget *settingsWidget = new QWidget( m_providerSettingsDialog );
+    QWidget *settingsWidget = new QWidget();
     m_providerSettingsDialog->setObjectName( QStringLiteral("SqlPodcastProviderSettings") );
     Ui::SqlPodcastProviderSettingsWidget settings;
     m_providerSettingsWidget = &settings;
@@ -605,7 +606,14 @@ SqlPodcastProvider::configureProvider()
             i18nc( "prefix to 'x minutes'", "every " ) );
     settings.m_autoUpdateInterval->setSuffix( i18np( " minute", " minutes", settings.m_autoUpdateInterval->value() ) );
 
-    auto buttonBox = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Apply, m_providerSettingsDialog );
+    auto buttonBox = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Apply );
+
+    m_providerSettingsDialog->setLayout( new QVBoxLayout );
+    m_providerSettingsDialog->layout()->addWidget( settingsWidget );
+    m_providerSettingsDialog->layout()->addWidget( buttonBox );
+
+    connect( buttonBox, &QDialogButtonBox::accepted, m_providerSettingsDialog, &QDialog::accept );
+    connect( buttonBox, &QDialogButtonBox::rejected, m_providerSettingsDialog, &QDialog::reject );
 
     connect( settings.m_baseDirUrl, &KUrlRequester::textChanged, this, &SqlPodcastProvider::slotConfigChanged );
     connect( settings.m_autoUpdateInterval, QOverload<int>::of(&QSpinBox::valueChanged),
@@ -637,7 +645,7 @@ SqlPodcastProvider::configureProvider()
 
                 if( button == QMessageBox::Yes )
                 {
-                    foreach( SqlPodcastChannelPtr sqlChannel, m_channels )
+                    for( SqlPodcastChannelPtr sqlChannel : m_channels )
                     {
                         QUrl oldSaveLocation = sqlChannel->saveLocation();
                         QUrl newSaveLocation = m_baseDownloadDir;
@@ -683,13 +691,13 @@ SqlPodcastProvider::slotExportOpml()
     //TODO: set header data such as date
 
     //TODO: folder outline support
-    foreach( SqlPodcastChannelPtr channel, m_channels )
+    for( SqlPodcastChannelPtr channel : m_channels )
     {
         OpmlOutline *channelOutline = new OpmlOutline();
         #define addAttr( k, v ) channelOutline->addAttribute( k, v )
-        addAttr( "text", channel->title() );
-        addAttr( "type", "rss" );
-        addAttr( "xmlUrl", channel->url().url() );
+        addAttr( QStringLiteral("text"), channel->title() );
+        addAttr( QStringLiteral("type"), QStringLiteral("rss") );
+        addAttr( QStringLiteral("xmlUrl"), channel->url().url() );
         rootOutlines << channelOutline;
     }
 
@@ -777,7 +785,7 @@ SqlPodcastProvider::configureChannel( Podcasts::SqlPodcastChannelPtr sqlChannel
 void
 SqlPodcastProvider::deleteDownloadedEpisodes( Podcasts::SqlPodcastEpisodeList &episodes )
 {
-    foreach( Podcasts::SqlPodcastEpisodePtr episode, episodes )
+    for( Podcasts::SqlPodcastEpisodePtr episode : episodes )
         deleteDownloadedEpisode( episode );
 }
 
@@ -788,7 +796,7 @@ SqlPodcastProvider::moveDownloadedEpisodes( Podcasts::SqlPodcastChannelPtr sqlCh
             .arg( sqlChannel->title(),
                   sqlChannel->saveLocation().toDisplayString() );
 
-    foreach( Podcasts::SqlPodcastEpisodePtr episode, sqlChannel->sqlEpisodes() )
+    for( Podcasts::SqlPodcastEpisodePtr episode : sqlChannel->sqlEpisodes() )
     {
         if( !episode->localUrl().isEmpty() )
         {
@@ -826,7 +834,7 @@ SqlPodcastProvider::slotDownloadEpisodes()
         return;
     Podcasts::SqlPodcastEpisodeList episodes = action->data().value<Podcasts::SqlPodcastEpisodeList>();
 
-    foreach( Podcasts::SqlPodcastEpisodePtr episode, episodes )
+    for( Podcasts::SqlPodcastEpisodePtr episode : episodes )
         downloadEpisode( episode );
 }
 
@@ -839,7 +847,7 @@ SqlPodcastProvider::slotSetKeep()
 
     Podcasts::SqlPodcastEpisodeList episodes = action->data().value<Podcasts::SqlPodcastEpisodeList>();
 
-    foreach( Podcasts::SqlPodcastEpisodePtr episode, episodes )
+    for( Podcasts::SqlPodcastEpisodePtr episode : episodes )
         episode->setKeep( action->isChecked() );
 }
 
@@ -868,7 +876,7 @@ SqlPodcastProvider::slotRemoveChannels()
 
     Podcasts::SqlPodcastChannelList channels = action->data().value<Podcasts::SqlPodcastChannelList>();
 
-    foreach( Podcasts::SqlPodcastChannelPtr channel, channels )
+    for( Podcasts::SqlPodcastChannelPtr channel : channels )
     {
         QPair<bool, bool> result = confirmUnsubscribe( channel );        
         if( result.first )
@@ -893,7 +901,7 @@ SqlPodcastProvider::slotUpdateChannels()
             return;
     Podcasts::SqlPodcastChannelList channels = action->data().value<Podcasts::SqlPodcastChannelList>();
 
-    foreach( Podcasts::SqlPodcastChannelPtr channel, channels )
+    for( Podcasts::SqlPodcastChannelPtr channel : channels )
             updateSqlChannel( channel );
 }
 
@@ -904,7 +912,7 @@ SqlPodcastProvider::slotDownloadProgress( KJob *job, unsigned long percent )
     Q_UNUSED( percent );
 
     unsigned int totalDownloadPercentage = 0;
-    foreach( const KJob *jobKey, m_downloadJobMap.keys() )
+    for( const KJob *jobKey : m_downloadJobMap.keys() )
         totalDownloadPercentage += jobKey->percent();
 
     //keep the completed jobs in mind as well.
@@ -922,7 +930,7 @@ SqlPodcastProvider::slotWriteTagsToFiles()
         return;
 
     Podcasts::SqlPodcastEpisodeList episodes = action->data().value<Podcasts::SqlPodcastEpisodeList>();
-    foreach( Podcasts::SqlPodcastEpisodePtr episode, episodes )
+    for( Podcasts::SqlPodcastEpisodePtr episode : episodes )
         episode->writeTagsToFile();
 }
 
@@ -981,7 +989,7 @@ SqlPodcastProvider::completePodcastDownloads()
                                       );
         progressDialog.setValue( 0 );
         m_completedDownloads = 0;
-        foreach( KJob *job, m_downloadJobMap.keys() )
+        for( KJob *job : m_downloadJobMap.keys() )
         {
             connect( job, SIGNAL(percent(KJob*,ulong)),
                      this, SLOT(slotDownloadProgress(KJob*,ulong))
@@ -992,7 +1000,7 @@ SqlPodcastProvider::completePodcastDownloads()
         int result = progressDialog.exec();
         if( result == QDialog::Rejected )
         {
-            foreach( KJob *job, m_downloadJobMap.keys() )
+            for( KJob *job : m_downloadJobMap.keys() )
             {
                 job->kill();
             }
@@ -1003,14 +1011,16 @@ SqlPodcastProvider::completePodcastDownloads()
 void
 SqlPodcastProvider::autoUpdate()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QNetworkConfigurationManager mgr;
     if( !mgr.isOnline() )
     {
         debug() << "Solid reports we are not online, canceling podcast auto-update";
         return;
     }
+#endif
 
-    foreach( Podcasts::SqlPodcastChannelPtr channel, m_channels )
+    for( Podcasts::SqlPodcastChannelPtr channel : m_channels )
     {
         if( channel->autoScan() )
             updateSqlChannel( channel );
@@ -1024,8 +1034,8 @@ SqlPodcastProvider::updateSqlChannel( Podcasts::SqlPodcastChannelPtr channel )
         return;
     if( m_updatingChannels >= m_maxConcurrentUpdates )
     {
-        debug() << QString( "Maximum concurrent updates (%1) reached. "
-                            "Queueing \"%2\" for download." )
+        debug() << QStringLiteral( "Maximum concurrent updates (%1) reached. "
+                                   "Queueing \"%2\" for download." )
                 .arg( m_maxConcurrentUpdates )
                 .arg( channel->title() );
         m_updateQueue << channel;
@@ -1110,7 +1120,7 @@ SqlPodcastProvider::downloadEpisode( Podcasts::SqlPodcastEpisodePtr sqlEpisode )
         return;
     }
 
-    foreach( struct PodcastEpisodeDownload download, m_downloadJobMap )
+    for( struct PodcastEpisodeDownload download : m_downloadJobMap )
     {
         if( download.episode == sqlEpisode )
         {
@@ -1121,8 +1131,8 @@ SqlPodcastProvider::downloadEpisode( Podcasts::SqlPodcastEpisodePtr sqlEpisode )
 
     if( m_downloadJobMap.size() >= m_maxConcurrentDownloads )
     {
-        debug() << QString( "Maximum concurrent downloads (%1) reached. "
-                            "Queueing \"%2\" for download." )
+        debug() << QStringLiteral( "Maximum concurrent downloads (%1) reached. "
+                                   "Queueing \"%2\" for download." )
                 .arg( m_maxConcurrentDownloads )
                 .arg( sqlEpisode->title() );
         //put into a FIFO which is used in downloadResult() to start a new download
@@ -1228,13 +1238,13 @@ SqlPodcastProvider::createTmpFile( Podcasts::SqlPodcastEpisodePtr sqlEpisode )
     //TODO: what if result is false?
 
     QUrl localUrl = QUrl::fromLocalFile( dir.absolutePath() );
-    QString tempName;
+    QByteArray tempName;
     if( !sqlEpisode->guid().isEmpty() )
         tempName = QUrl::toPercentEncoding( sqlEpisode->guid() );
     else
         tempName = QUrl::toPercentEncoding( sqlEpisode->uidUrl() );
 
-    QString tempNameMd5( QCryptographicHash::hash( tempName.toUtf8(), QCryptographicHash::Md5 ).toHex() );
+    QLatin1String tempNameMd5( QCryptographicHash::hash( tempName, QCryptographicHash::Md5 ).toHex() );
 
     localUrl = localUrl.adjusted(QUrl::StripTrailingSlash);
     localUrl.setPath(localUrl.path() + QLatin1Char('/') + ( tempNameMd5 + PODCAST_TMP_POSTFIX ));
@@ -1435,34 +1445,34 @@ SqlPodcastProvider::createTables() const
     if( !sqlStorage )
         return;
 
-    sqlStorage->query( QString( "CREATE TABLE podcastchannels ("
-                                "id " + sqlStorage->idType() +
-                                ",url " + sqlStorage->longTextColumnType() +
-                                ",title " + sqlStorage->longTextColumnType() +
-                                ",weblink " + sqlStorage->longTextColumnType() +
-                                ",image " + sqlStorage->longTextColumnType() +
-                                ",description " + sqlStorage->longTextColumnType() +
-                                ",copyright "  + sqlStorage->textColumnType() +
-                                ",directory "  + sqlStorage->textColumnType() +
-                                ",labels " + sqlStorage->textColumnType() +
-                                ",subscribedate " + sqlStorage->textColumnType() +
-                                ",autoscan BOOL, fetchtype INTEGER"
+    sqlStorage->query( QStringLiteral( "CREATE TABLE podcastchannels ("
+                                "id ") + sqlStorage->idType() +
+                                QStringLiteral(",url ") + sqlStorage->longTextColumnType() +
+                                QStringLiteral(",title ") + sqlStorage->longTextColumnType() +
+                                QStringLiteral(",weblink ") + sqlStorage->longTextColumnType() +
+                                QStringLiteral(",image ") + sqlStorage->longTextColumnType() +
+                                QStringLiteral(",description ") + sqlStorage->longTextColumnType() +
+                                QStringLiteral(",copyright ")  + sqlStorage->textColumnType() +
+                                QStringLiteral(",directory ")  + sqlStorage->textColumnType() +
+                                QStringLiteral(",labels ") + sqlStorage->textColumnType() +
+                                QStringLiteral(",subscribedate ") + sqlStorage->textColumnType() +
+                                QStringLiteral(",autoscan BOOL, fetchtype INTEGER"
                                 ",haspurge BOOL, purgecount INTEGER"
                                 ",writetags BOOL, filenamelayout VARCHAR(1024) ) ENGINE = MyISAM;" ) );
 
-    sqlStorage->query( QString( "CREATE TABLE podcastepisodes ("
-                                "id " + sqlStorage->idType() +
-                                ",url " + sqlStorage->longTextColumnType() +
-                                ",channel INTEGER"
-                                ",localurl " + sqlStorage->longTextColumnType() +
-                                ",guid " + sqlStorage->exactTextColumnType() +
-                                ",title " + sqlStorage->longTextColumnType() +
-                                ",subtitle " + sqlStorage->longTextColumnType() +
-                                ",sequencenumber INTEGER" +
-                                ",description " + sqlStorage->longTextColumnType() +
-                                ",mimetype "  + sqlStorage->textColumnType() +
-                                ",pubdate "  + sqlStorage->textColumnType() +
-                                ",duration INTEGER"
+    sqlStorage->query( QStringLiteral( "CREATE TABLE podcastepisodes ("
+                                "id ") + sqlStorage->idType() +
+                                QStringLiteral(",url ") + sqlStorage->longTextColumnType() +
+                                QStringLiteral(",channel INTEGER"
+                                ",localurl ") + sqlStorage->longTextColumnType() +
+                                QStringLiteral(",guid ") + sqlStorage->exactTextColumnType() +
+                                QStringLiteral(",title ") + sqlStorage->longTextColumnType() +
+                                QStringLiteral(",subtitle ") + sqlStorage->longTextColumnType() +
+                                QStringLiteral(",sequencenumber INTEGER"
+                                ",description ") + sqlStorage->longTextColumnType() +
+                                QStringLiteral(",mimetype ")  + sqlStorage->textColumnType() +
+                                QStringLiteral(",pubdate ")  + sqlStorage->textColumnType() +
+                                QStringLiteral(",duration INTEGER"
                                 ",filesize INTEGER"
                                 ",isnew BOOL"
                                 ",iskeep BOOL) ENGINE = MyISAM;" ) );
@@ -1486,8 +1496,8 @@ SqlPodcastProvider::updateDatabase( int fromVersion, int toVersion )
 
     if( fromVersion == 1 && toVersion == 2 )
     {
-        QString updateChannelQuery = QString( "ALTER TABLE podcastchannels"
-                                              " ADD subscribedate " + sqlStorage->textColumnType() + ';' );
+        QString updateChannelQuery = QStringLiteral( "ALTER TABLE podcastchannels"
+                                              " ADD subscribedate ") + sqlStorage->textColumnType() + QLatin1Char(';');
 
         sqlStorage->query( updateChannelQuery );
 
@@ -1498,33 +1508,33 @@ SqlPodcastProvider::updateDatabase( int fromVersion, int toVersion )
     }
     else if( fromVersion < 3 && toVersion == 3 )
     {
-        sqlStorage->query( QString( "CREATE TABLE podcastchannels_temp ("
-                                    "id " + sqlStorage->idType() +
-                                    ",url " + sqlStorage->exactTextColumnType() + " UNIQUE"
-                                    ",title " + sqlStorage->textColumnType() +
-                                    ",weblink " + sqlStorage->exactTextColumnType() +
-                                    ",image " + sqlStorage->exactTextColumnType() +
-                                    ",description " + sqlStorage->longTextColumnType() +
-                                    ",copyright "  + sqlStorage->textColumnType() +
-                                    ",directory "  + sqlStorage->textColumnType() +
-                                    ",labels " + sqlStorage->textColumnType() +
-                                    ",subscribedate " + sqlStorage->textColumnType() +
-                                    ",autoscan BOOL, fetchtype INTEGER"
+        sqlStorage->query( QStringLiteral( "CREATE TABLE podcastchannels_temp ("
+                                    "id ") + sqlStorage->idType() +
+                                    QStringLiteral(",url ") + sqlStorage->exactTextColumnType() + QStringLiteral(" UNIQUE"
+                                    ",title ") + sqlStorage->textColumnType() +
+                                    QStringLiteral(",weblink ") + sqlStorage->exactTextColumnType() +
+                                    QStringLiteral(",image ") + sqlStorage->exactTextColumnType() +
+                                    QStringLiteral(",description ") + sqlStorage->longTextColumnType() +
+                                    QStringLiteral(",copyright ")  + sqlStorage->textColumnType() +
+                                    QStringLiteral(",directory ")  + sqlStorage->textColumnType() +
+                                    QStringLiteral(",labels ") + sqlStorage->textColumnType() +
+                                    QStringLiteral(",subscribedate ") + sqlStorage->textColumnType() +
+                                    QStringLiteral(",autoscan BOOL, fetchtype INTEGER"
                                     ",haspurge BOOL, purgecount INTEGER ) ENGINE = MyISAM;" ) );
 
-        sqlStorage->query( QString( "CREATE TABLE podcastepisodes_temp ("
-                                    "id " + sqlStorage->idType() +
-                                    ",url " + sqlStorage->exactTextColumnType() + " UNIQUE"
+        sqlStorage->query( QStringLiteral( "CREATE TABLE podcastepisodes_temp ("
+                                    "id ") + sqlStorage->idType() +
+                                    QStringLiteral(",url ") + sqlStorage->exactTextColumnType() + QStringLiteral(" UNIQUE"
                                     ",channel INTEGER"
-                                    ",localurl " + sqlStorage->exactTextColumnType() +
-                                    ",guid " + sqlStorage->exactTextColumnType() +
-                                    ",title " + sqlStorage->textColumnType() +
-                                    ",subtitle " + sqlStorage->textColumnType() +
-                                    ",sequencenumber INTEGER" +
-                                    ",description " + sqlStorage->longTextColumnType() +
-                                    ",mimetype "  + sqlStorage->textColumnType() +
-                                    ",pubdate "  + sqlStorage->textColumnType() +
-                                    ",duration INTEGER"
+                                    ",localurl ") + sqlStorage->exactTextColumnType() +
+                                    QStringLiteral(",guid ") + sqlStorage->exactTextColumnType() +
+                                    QStringLiteral(",title ") + sqlStorage->textColumnType() +
+                                    QStringLiteral(",subtitle ") + sqlStorage->textColumnType() +
+                                    QStringLiteral(",sequencenumber INTEGER"
+                                    ",description ") + sqlStorage->longTextColumnType() +
+                                    QStringLiteral(",mimetype ")  + sqlStorage->textColumnType() +
+                                    QStringLiteral(",pubdate ")  + sqlStorage->textColumnType() +
+                                    QStringLiteral(",duration INTEGER"
                                     ",filesize INTEGER"
                                     ",isnew BOOL"
                                     ",iskeep BOOL) ENGINE = MyISAM;" ) );
@@ -1546,18 +1556,18 @@ SqlPodcastProvider::updateDatabase( int fromVersion, int toVersion )
 
     if( fromVersion < 4 && toVersion == 4 )
     {
-        QString updateChannelQuery = QString( "ALTER TABLE podcastchannels"
+        QString updateChannelQuery = QStringLiteral( "ALTER TABLE podcastchannels"
                                               " ADD writetags BOOL;" );
         sqlStorage->query( updateChannelQuery );
-        QString setWriteTagsQuery = QString( "UPDATE podcastchannels SET writetags=" +
+        QString setWriteTagsQuery = QStringLiteral( "UPDATE podcastchannels SET writetags=") +
                                              sqlStorage->boolTrue() +
-                                             " WHERE 1;" );
+                                             QStringLiteral(" WHERE 1;" );
         sqlStorage->query( setWriteTagsQuery );
     }
 
     if( fromVersion < 5 && toVersion == 5 )
     {
-        QString updateChannelQuery = QString ( "ALTER TABLE podcastchannels"
+        QString updateChannelQuery = QStringLiteral ( "ALTER TABLE podcastchannels"
                                                " ADD filenamelayout VARCHAR(1024);" );
         sqlStorage->query( updateChannelQuery );
         QString setWriteTagsQuery = QStringLiteral( "UPDATE podcastchannels SET filenamelayout='%default%'" );
@@ -1566,7 +1576,7 @@ SqlPodcastProvider::updateDatabase( int fromVersion, int toVersion )
 
     if( fromVersion < 6 && toVersion == 6 )
     {
-        QString updateEpisodeQuery = QString ( "ALTER TABLE podcastepisodes"
+        QString updateEpisodeQuery = QStringLiteral ( "ALTER TABLE podcastepisodes"
                                                " ADD iskeep BOOL;" );
         sqlStorage->query( updateEpisodeQuery );
         QString setIsKeepQuery = QStringLiteral( "UPDATE podcastepisodes SET iskeep=FALSE;" );
