@@ -28,8 +28,6 @@
 #include "dialogs/DatabaseImporterDialog.h"
 
 #include <KLocalizedString>
-#include <QPushButton>
-#include <QVBoxLayout>
 
 #include <QAction>
 #include <QApplication>
@@ -38,6 +36,8 @@
 #include <QFile>
 #include <QLabel>
 #include <QMenu>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 #include <algorithm>
 
@@ -52,7 +52,7 @@ CollectionSetup::CollectionSetup( QWidget *parent )
 
     setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );
 
-    setObjectName( "CollectionSetup" );
+    setObjectName( QStringLiteral("CollectionSetup") );
     s_instance = this;
 
     m_ui.view->setAnimated( true );
@@ -64,11 +64,11 @@ CollectionSetup::CollectionSetup( QWidget *parent )
     connect( m_rescanDirAction, &QAction::triggered,
              this, &CollectionSetup::slotRescanDirTriggered );
 
-    QPushButton *rescan = new QPushButton( QIcon::fromTheme( "collection-rescan-amarok" ), i18n( "Full rescan" ), m_ui.buttonContainer );
+    QPushButton *rescan = new QPushButton( QIcon::fromTheme( QStringLiteral("collection-rescan-amarok") ), i18n( "Full rescan" ), m_ui.buttonContainer );
     rescan->setToolTip( i18n( "Rescan your entire collection. This will <i>not</i> delete any statistics." ) );
     connect( rescan, &QAbstractButton::clicked, CollectionManager::instance(), &CollectionManager::startFullScan );
 
-    QPushButton *import = new QPushButton( QIcon::fromTheme( "tools-wizard" ), i18n( "Import batch file..." ), m_ui.buttonContainer );
+    QPushButton *import = new QPushButton( QIcon::fromTheme( QStringLiteral("tools-wizard") ), i18n( "Import batch file..." ), m_ui.buttonContainer );
     import->setToolTip( i18n( "Import collection from file produced by amarokcollectionscanner." ) );
     connect( import, &QAbstractButton::clicked, this, &CollectionSetup::importCollection );
 
@@ -108,7 +108,7 @@ CollectionSetup::CollectionSetup( QWidget *parent )
     m_model->setDirectories( dirs );
 
     // make sure that the tree is expanded to show all selected items
-    foreach( const QString &dir, dirs )
+    for( const QString &dir : dirs )
     {
         QModelIndex index = m_model->index( dir );
         m_ui.view->scrollTo( index, QAbstractItemView::EnsureVisible );
@@ -210,7 +210,7 @@ CollectionSetup::isDirInCollection( const QString& path ) const
     Collections::Collection *primaryCollection = CollectionManager::instance()->primaryCollection();
     QStringList collectionFolders = primaryCollection ? primaryCollection->property( "collectionFolders" ).toStringList() : QStringList();
 
-    foreach( const QString &dir, collectionFolders )
+    for( const QString &dir : collectionFolders )
     {
         debug() << "Collection Location: " << dir;
         debug() << "path: " << path;
@@ -218,7 +218,7 @@ CollectionSetup::isDirInCollection( const QString& path ) const
         QUrl parentUrl = QUrl::fromLocalFile( dir );
         if ( !AmarokConfig::scanRecursively() )
         {
-            if ( ( dir == path ) || ( QString( dir + '/' ) == path ) )
+            if ( ( dir == path ) || ( QString( dir + QLatin1Char('/') ) == path ) )
                 return true;
         }
         else //scan recursively
@@ -286,7 +286,8 @@ namespace CollectionFolder {
                     // Recursive, so clear any paths in m_checked that are made
                     // redundant by this new selection
                     QString _path = normalPath( path );
-                    foreach( const QString &elem, m_checked )
+                    const auto checks = m_checked;
+                    for( const QString &elem : checks )
                     {
                         if( normalPath( elem ).startsWith( _path ) )
                             m_checked.remove( elem );
@@ -329,7 +330,7 @@ namespace CollectionFolder {
     Model::setDirectories( const QStringList &dirs )
     {
         m_checked.clear();
-        foreach( const QString &dir, dirs )
+        for( const QString &dir : dirs )
         {
             m_checked.insert( dir );
         }
@@ -346,7 +347,7 @@ namespace CollectionFolder {
         // they are redundant when recursive mode is chosen
         if( recursive() )
         {
-            foreach( const QString &dir, dirs )
+            for( const QString &dir : dirs )
             {
                 if( ancestorChecked( dir ) )
                     dirs.removeAll( dir );
@@ -361,7 +362,7 @@ namespace CollectionFolder {
     {
         // we need the trailing slash otherwise we could forbid "/dev-music" for example
         QString _path = normalPath( path );
-        return _path.startsWith( "/proc/" ) || _path.startsWith( "/dev/" ) || _path.startsWith( "/sys/" );
+        return _path.startsWith( QStringLiteral("/proc/") ) || _path.startsWith( QStringLiteral("/dev/") ) || _path.startsWith( QStringLiteral("/sys/") );
     }
 
     bool
@@ -370,7 +371,7 @@ namespace CollectionFolder {
         // we need the trailing slash otherwise sibling folders with one as the prefix of the other are seen as parent/child
         const QString _path = normalPath( path );
 
-        foreach( const QString &element, m_checked )
+        for( const QString &element : m_checked )
         {
             const QString _element = normalPath( element );
             if( _path.startsWith( _element ) && _element != _path )
@@ -388,7 +389,7 @@ namespace CollectionFolder {
     {
         const QString _path = normalPath( path );
         QStringList rtn;
-        foreach( const QString &element, m_checked )
+        for( const QString &element : m_checked )
         {
             const QString _element = normalPath( element );
             if ( _path.startsWith( _element ) && _element != _path )
@@ -403,7 +404,7 @@ namespace CollectionFolder {
         // we need the trailing slash otherwise sibling folders with one as the prefix of the other are seen as parent/child
         const QString _path = normalPath( path );
 
-        foreach( const QString& element, m_checked )
+        for( const QString &element : m_checked )
         {
             const QString _element = normalPath( element );
             if( _element.startsWith( _path ) && _element != _path )
@@ -423,7 +424,7 @@ namespace CollectionFolder {
         while( it.hasNext() )
         {
             QString nextPath = it.next();
-            if( nextPath.endsWith( "/." ) || nextPath.endsWith( "/.." ) )
+            if( nextPath.endsWith( QStringLiteral("/.") ) || nextPath.endsWith( QStringLiteral("/..") ) )
                 continue;
             if( !_excludePath.startsWith( nextPath ) )
                 m_checked << nextPath;
