@@ -35,18 +35,45 @@ Playlist::StandardTrackNavigator::StandardTrackNavigator()
 }
 
 quint64
-Playlist::StandardTrackNavigator::likelyLastTrack()
+Playlist::StandardTrackNavigator::chooseLastTrack( bool repeatPlaylist )
 {
-    int lastRow = m_model->activeRow() - 1;
+    Meta::TrackPtr track;
+    bool playableTrackFound = false;
+    int lastRow;
+
+    // reminder: if that function is modified, it's important to research if changes must also
+    // be applied to similar code in `Playlist::StandardTrackNavigator::chooseNextTrack()`
+
+    // search for a playable track in order from right before the currently active track till the start
+    for ( lastRow = m_model->activeRow() - 1  ; lastRow >= 0 ; lastRow-- ) // 'activeRow()' may be -1
+    {
+        track = m_model->trackAt(lastRow);
+        if ( track->isPlayable() )
+        {
+            playableTrackFound = true;
+            break;
+        }
+    }
 
     // Even though the user is explicitly asking us to go back, still only do wrap-around
     // in mode 'm_repeatPlaylist'. Reason: many users of the standard navigator like to
     // move to the start of the playlist by blindly pressing "Prev" a lot of times.
-    if( lastRow < 0 )
-        if( m_repeatPlaylist )
-            lastRow = m_model->qaim()->rowCount() - 1;    // This row is still invalid if 'rowCount() == 0'.
+    // If no playable track was found, the playlist needs to be repeated, it's not empty
+    // and there's an active track: search from end of playlist till currently active track.
+    if ( !playableTrackFound && repeatPlaylist && m_model->qaim()->rowCount() > 0 && m_model->activeRow() >= 0)
+    {
+        for ( lastRow = m_model->qaim()->rowCount() - 1 ; lastRow >= m_model->activeRow() ; lastRow--)
+        {
+            track = m_model->trackAt( lastRow );
+            if ( track->isPlayable() )
+            {
+                playableTrackFound = true;
+                break;
+            }
+        }
+    }
 
-    if( m_model->rowExists( lastRow ) )
+    if ( playableTrackFound && m_model->rowExists( lastRow ) )
         return m_model->idAt( lastRow );
     else
         return 0;
@@ -80,7 +107,13 @@ Playlist::StandardTrackNavigator::requestUserNextTrack()
 quint64
 Playlist::StandardTrackNavigator::requestLastTrack()
 {
-    return likelyLastTrack();
+    if( !m_queue.isEmpty() ) {
+        quint64 ret = m_queue.takeFirst();
+        Playlist::ModelStack::instance()->bottom()->emitQueueChanged();
+        return ret;
+    }
+
+    return chooseLastTrack( m_repeatPlaylist );
 }
 
 quint64
@@ -96,6 +129,9 @@ Playlist::StandardTrackNavigator::chooseNextTrack( bool repeatPlaylist )
     bool playableTrackFound = false;
     int nextRow;
 
+    // reminder: if that function is modified, it's important to research if changes must also
+    // be applied to similar code in `Playlist::StandardTrackNavigator::chooseLastTrack()`
+
     //search for a playable track in order from right after the currently active track till the end
     for( nextRow = m_model->activeRow() + 1  ; nextRow < m_model->qaim()->rowCount() ; nextRow++ ) // 'activeRow()' may be -1.
     {
