@@ -29,11 +29,8 @@
 #include <QListWidget>
 #include <QKeyEvent>
 #include <QMenuBar>
-#include <QJSEngine>
 #include <QRandomGenerator>
 #include <QSettings>
-#include <QStandardPaths>
-#include <QTemporaryFile>
 #include <QToolBar>
 
 #include <KMessageBox>
@@ -85,7 +82,7 @@ ScriptConsole::ScriptConsole( QWidget *parent )
                     << m_consoleWidget
                     << m_outputWidget
                     << m_errorWidget;
-    foreach( QDockWidget *widget, debugWidgets )
+    for( QDockWidget *widget : debugWidgets )
     {
       addDockWidget( Qt::BottomDockWidgetArea, widget );
     }
@@ -102,11 +99,11 @@ ScriptConsole::ScriptConsole( QWidget *parent )
     connect( action, &QAction::toggled, this, &ScriptConsole::slotAbortEvaluation );
     toolBar->addAction( action );
     action = new QAction( QIcon::fromTheme( QStringLiteral("media-playback-start") ), i18n("Execute Script"), this );
-    action->setShortcut( Qt::CTRL + Qt::Key_Enter );
+    action->setShortcut( Qt::CTRL | Qt::Key_Enter );
     connect( action, &QAction::triggered, this, &ScriptConsole::slotExecuteNewScript );
     toolBar->addAction( action );
     action = new QAction( QIcon::fromTheme( QStringLiteral("document-new") ), i18n( "&New Script" ), this );
-    action->setShortcut( Qt::CTRL + Qt::Key_N );
+    action->setShortcut( Qt::CTRL | Qt::Key_N );
     toolBar->addAction( action );
     connect( action, &QAction::triggered, this, &ScriptConsole::slotNewScript );
     action = new QAction( QIcon::fromTheme( QStringLiteral("edit-delete") ), i18n( "&Delete Script" ), this );
@@ -128,7 +125,8 @@ ScriptConsole::ScriptConsole( QWidget *parent )
 
     QMenu *viewMenu = new QMenu( this );
     viewMenu->setTitle( i18n( "&View" ) );
-    foreach( QDockWidget *dockWidget, findChildren<QDockWidget*>() )
+    auto dwlist = findChildren<QDockWidget*>();
+    for( QDockWidget *dockWidget : dwlist )
     {
         if( dockWidget->parentWidget() == this )
             viewMenu->addAction( dockWidget->toggleViewAction() );
@@ -139,12 +137,12 @@ ScriptConsole::ScriptConsole( QWidget *parent )
     connect( m_scriptListDock, &ScriptListDockWidget::edit, this, &ScriptConsole::slotEditScript );
     connect( m_scriptListDock, &ScriptListDockWidget::currentItemChanged, this, &ScriptConsole::setCurrentScriptItem );
 
-    QListWidgetItem *item = new QListWidgetItem( "The Amarok Script Console allows you to easily execute"
+    QListWidgetItem *item = new QListWidgetItem( QStringLiteral( "The Amarok Script Console allows you to easily execute"
                                                 "JavaScript with access to all functions\nand methods you would"
                                                 "have in an Amarok script.\nInformation on scripting for Amarok is"
                                                 "available at:\nhttp://community.kde.org/Amarok/Development#Scripting"
                                                 "\nExecute code: CTRL-Enter\nBack in code history: Page Up"
-                                                "\nForward in code history: Page Down"
+                                                "\nForward in code history: Page Down")
                                                , nullptr );
     item->setFlags( Qt::NoItemFlags );
     m_scriptListDock->addItem( item );
@@ -166,10 +164,10 @@ ScriptConsole::ScriptConsole( QWidget *parent )
     qInstallMessageHandler( [] ( QtMsgType type, const QMessageLogContext &context, const QString &msg )
     {
         Q_UNUSED( type );
-        QString category(context.category);
-        if ( category.compare( "js" ) == 0 ) {
+        QString category(QLatin1String(context.category));
+        if ( category.compare( QStringLiteral("js") ) == 0 ) {
 
-            QString scriptName( context.file );
+            QString scriptName( QLatin1String(context.file) );
             // clean "file:" from file name
             scriptName.remove( 0, 5);
 
@@ -177,7 +175,7 @@ ScriptConsole::ScriptConsole( QWidget *parent )
             ScriptConsoleItem *searchResult = instance()->getScriptListDockWidget()->getScript( scriptName );
             if (searchResult != nullptr ) {
                 // Found it - update its console widget
-                QString logEntry = QString("[%1: %2] %3")
+                QString logEntry = QStringLiteral("[%1: %2] %3")
                 .arg( scriptName )
                 .arg( context.line )
                 .arg( msg );
